@@ -1,6 +1,9 @@
-( cd usr/share/doc/gnome-keyring-manager-0.0.3 ; rm -rf build )
-( cd usr/share/doc/gnome-keyring-manager-0.0.3 ; ln -sf /usr/src/garnome-Ptgz-kit build )
-#%% begin initialize gnome_keyring_manager-0.0.3-i386-P1
+( cd usr/share/doc/gnome-keyring-manager-2.12.0 ; rm -rf build )
+( cd usr/share/doc/gnome-keyring-manager-2.12.0 ; ln -sf /usr/src/garnome-Ptgz-kit build )
+#%% begin initialize gnome_keyring_manager-2.12.0-i386-P1
+if [ -x /usr/bin/scrollkeeper-update ]; then
+  /usr/bin/scrollkeeper-update -q || exit 1
+fi
 GCONFTOOL=/usr/bin/gconftool-2
 if [ ! -x $GCONFTOOL ]; then
   exit 1
